package de.meinefirma.meinprojekt.crypto;

import java.io.File;
import java.io.IOException;
import java.security.GeneralSecurityException;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Date;
import java.util.Locale;

import org.junit.Assert;
import org.junit.Test;

/**
 * Mit dieser Testklasse kann die Performance der Ver- und Entschluesselung gemessen werden.
 * Die Messung wird nur ausgefuehrt, wenn im Projektverzeichnis eine Datei mit dem Namen
 * "MeineZuVerschluesselndeTestDatei" hinterlegt wird.
 */
public class OpenPgpBouncyCastleStreamUtilPerformanceTest
{
   @Test
   public void testBcStreamFile() throws GeneralSecurityException, IOException
   {
      String srcFile        = "MeineZuVerschluesselndeTestDatei";
      String dstFile        = "target/" + srcFile + ".decrypted";
      String encFile        = "target/" + srcFile + ".bpg";
      String keyIdName      = "MeinName (BC-Test) <ich@myserver.de>";
      String passphrase     = "Meine geheime BC-Passphrase 42";
      String privateKeyFile = "target/PrivateKey.rsa";
      String publicKeyFile  = "target/PublicKey.rsa";

      OpenPgpBouncyCastleStreamUtil.addBouncyCastleProvider();

      if( !(new File( srcFile ).exists()) ) { return; }

      (new File( dstFile )).delete();
      (new File( encFile )).delete();

      OpenPgpBouncyCastleStreamUtil.generateKeyPairFiles( privateKeyFile, publicKeyFile, keyIdName, passphrase, true );
      Assert.assertTrue( new File( privateKeyFile ).exists() );
      Assert.assertTrue( new File( publicKeyFile ).exists() );

      long t1 = (new Date()).getTime();
      OpenPgpBouncyCastleStreamUtil.encryptFile( encFile, srcFile, publicKeyFile, false, true );
      long t2 = (new Date()).getTime();
      System.out.println( "\n" + ((t2 - t1) / 1000.) + " s" );
      Assert.assertTrue( new File( encFile ).exists() );

      Assert.assertFalse( new File( dstFile ).exists() );
      long t3 = (new Date()).getTime();
      OpenPgpBouncyCastleStreamUtil.decryptFile( dstFile, encFile, privateKeyFile, passphrase );
      long t4 = (new Date()).getTime();
      System.out.println( ((t4 - t3) / 1000.) + " s" );
      Assert.assertTrue( new File( dstFile ).exists() );

      long len = new File( srcFile ).length();
      System.out.println( "Dateigroesse: " + showSize( len ) );
      Assert.assertEquals( new File( dstFile ).length(), len );
   }

   String showSize( long bytes )
   {
      DecimalFormat df = (DecimalFormat) NumberFormat.getInstance( Locale.GERMAN );
      df.applyPattern( "#,###,##0.00" );
      if( bytes < 1024 ) { return bytes + " Byte\n"; }
      double d = bytes;
      if( (d /= 1024) < 1024 ) { return df.format( d ) + " KByte\n"; }
      if( (d /= 1024) < 1024 ) { return df.format( d ) + " MByte\n"; }
      return df.format( d /= 1024 ) + " GByte\n";
   }
}
