package de.meinefirma.meinprojekt.crypto;

import java.io.*;
import java.util.List;
import java.util.zip.DataFormatException;
import de.idyl.winzipaes.*;
import de.idyl.winzipaes.impl.*;

/**
 * @see http://code.google.com/p/winzipaes
 * @see http://www.bouncycastle.org
 * @see http://www.winzip.com/aes_info.htm
*/
public class CryptoWinZipAES
{
   public static void main( String[] args ) throws IOException, DataFormatException
   {
      if( args.length == 4 ) {
         if( args[0].toLowerCase().startsWith( "e" ) || args[0].toLowerCase().startsWith( "z" ) ) {
            zipAndEncrypt( args[1], args[2], args[3] );
            return;
         } else if( args[0].toLowerCase().startsWith( "d" ) || args[0].toLowerCase().startsWith( "u" ) ) {
            unzipAndDecrypt( args[1], args[2], args[3] );
            return;
         }
      }
      System.out.println( "Fehler: Es werden vier Parameter benoetigt:\n" +
            "Zum Zippen und Verschluesseln:\n" +
            "  zip SrcFile DstZipFile Passwort\n" +
            "Zum Unzippen und Entschluesseln:\n" +
            "  unzip SrcZipFile DstDir Passwort\n" );
   }

   public static void zipAndEncrypt( String srcFile, String dstZipFile, String password ) throws IOException
   {
      AesZipFileEncrypter.zipAndEncrypt( new File( srcFile ), new File( dstZipFile ), password, new AESEncrypterBC() );
   }

   public static void zipAndEncrypt( List<String> srcFiles, String dstZipFile, String password ) throws IOException
   {
      AesZipFileEncrypter aesZip = new AesZipFileEncrypter( dstZipFile, new AESEncrypterBC() );
      for( String srcFile : srcFiles ) {
         aesZip.add( new File( srcFile ), password );
      }
      aesZip.close();
   }

   public static void unzipAndDecrypt( String srcZipFile, String dstDir, String password ) throws IOException, DataFormatException
   {
      String dir = ( dstDir == null ) ? "" : ( dstDir.endsWith( "/" ) || dstDir.endsWith( "\\" ) ) ? dstDir : (dstDir + "/");
      AesZipFileDecrypter decrypter = new AesZipFileDecrypter( new File( srcZipFile ), new AESDecrypterBC() );
      List<ExtZipEntry> zipEntries = decrypter.getEntryList();
      for( ExtZipEntry zipEntry : zipEntries ) {
         File outFile = new File( dir + zipEntry.getName() );
         String parentPath = outFile.getParent();
         if( parentPath != null && parentPath.trim().length() > 0 ) {
            File f = new File( parentPath );
            if( !f.exists() ) { f.mkdirs(); }
         }
         decrypter.extractEntry( zipEntry, outFile, password );
      }
   }
}
